==> jinrousiki-3.0.1_upgrade_3.0.0.zip: jinrousiki-3.0.1_upgrade_3.0.0/3.0.1_upgrade/info/develop/history.php <==
<?php
require_once('init.php');
InfoHTML::OutputHeader('開発履歴', 1, 'develop_history');
?>
<p>
Ver. 3.0.x<br>
<a href="#ver301">1</a>
</p>
Ver. 3.0.0<br>
<a href="#ver300rc1">RC1</a>
<a href="#ver300">Release</a>
<p>
<a href="#ver300a1">α1</a>
<a href="#ver300a2">α2</a>
<a href="#ver300a3">α3</a>
<a href="#ver300a4">α4</a>
<a href="#ver300a5">α5</a>
<a href="#ver300a6">α6</a>
<a href="#ver300a7">α7</a>
<a href="#ver300b1">β1</a>
</p>
<p>
<a href="history_1.3.php">～ 1.3</a>
<a href="history_1.4.php">1.4</a>
<a href="history_1.5.php">1.5</a>
<a href="history_2.0.php">2.0</a>
<a href="history_2.1.php">2.1</a>
<a href="history_2.2.php">2.2</a>
<a href="history_2.3.php">2.3</a>
</p>

<h2 id="ver301">Ver. 3.0.1 (Rev. 1236) : 2014/10/30 (Thu) 01:55</h2>
<ul>
<li>天狗の所属陣営を誤判定することがあるバグを修正</li>
<li>愛人を恋人カウントするバグ修正</li>
</ul>

<h2 id="ver300">Ver. 3.0.0 (Rev. 1203) : 2014/10/12 (Sun) 00:17</h2>
<ul>
<li>管理者向け情報追加</li>
<li>天候「新月」仕様変更</li>
<li>天候システム・闇鍋モードの背景画像追加</li>
</ul>

<h2 id="ver300rc1">Ver. 3.0.0 RC1 (Rev. 1193) : 2014/09/14 (Sun) 19:47</h2>
<ul>
<li>固定配役追加モード：U(背信村)追加</li>
<li>出現率変動モード：L(結束村)・M(天道村)追加</li>
<li>天候「天狗風」「無風」「彩雲」「星空」「花吹雪」実装</li>
</ul>

<h2 id="ver300b1">Ver. 3.0.0 β1 (Rev. 1184) : 2014/08/31 (Sun) 05:19</h2>
<ul>
<li>非同期更新システムを仮実装</li>
<li>背景画像変更：配役一覧</li>
<li>天狗：ショック死の仕様を変更</li>
<li>固定配役追加モード：T(天狗村)追加</li>
<li>「天変地異」オプション実装</li>
</ul>

<h2 id="ver300a7">Ver. 3.0.0 α7 (Rev. 1168) : 2014/08/12 (Tue) 02:17</h2>
<ul>
<li>Twitter 投稿モジュールのバージョンアップ</li>
<li>神通力の仕様変更</li>
<li>「流星天狗」「鼻高天狗」実装</li>
</ul>

<h2 id="ver300a6">Ver. 3.0.0 α6 (Rev. 1142) : 2014/07/22 (Tue) 02:37</h2>
<ul>
<li>ソースコードダウンロード削除</li>
<li>人狼襲撃失敗の要因を死亡者メッセージに表示</li>
<li>「文車妖妃」「目目連」「瞳狼」実装</li>
<li>サブ役職「交換日記」実装</li>
</ul>

<h2 id="ver300a5">Ver. 3.0.0 α5 (Rev. 1122) : 2014/07/02 (Wed) 00:09</h2>
<ul>
<li>「奉公童女」のバグ修正</li>
<li>「蛍火」の仕様変更</li>
<li>「沈黙禁止」オプション実装</li>
<li>「一言主神」「尼天狗」「産土神」実装</li>
</ul>

<h2 id="ver300a4">Ver. 3.0.0 α4 (Rev. 1106) : 2014/05/25 (Sun) 00:34</h2>
<ul>
<li>「玩具姫」「西行法師」「奉公童女」実装</li>
</ul>

<h2 id="ver300a3">Ver. 3.0.0 α3 (Rev. 1095) : 2014/04/27 (Sun) 21:31</h2>
<ul>
<li>「紂王」「虎狼」「虎狐」実装</li>
</ul>

<h2 id="ver300a2">Ver. 3.0.0 α2 (Rev. 1068) : 2014/04/07 (Mon) 02:06</h2>
<ul>
<li>「天狗」「大天狗」「木っ端天狗」実装</li>
<li>サブ役職「天狗倒し」実装</li>
</ul>

<h2 id="ver300a1">Ver. 3.0.0 α1 (Rev. 1051) : 2014/02/02 (Sun) 21:13</h2>
<ul>
<li>秘密発言追加</li>
<li>「発言数制限制」「秘密会話あり」オプション実装</li>
</ul>
</body>
</html>

==> jinrousiki-3.0.2_upgrade_3.0.1.zip: jinrousiki-3.0.2_upgrade_3.0.1/3.0.2_upgrade/info/develop/history.php <==
<?php
require_once('init.php');
InfoHTML::OutputHeader('開発履歴', 1, 'develop_history');
?>
<p>
Ver. 3.0.x<br>
<a href="#ver301">1</a>
<a href="#ver302">2</a>
</p>
<p>
Ver. 3.0.0<br>
<a href="#ver300rc1">RC1</a>
<a href="#ver300">Release</a>
<p>
<a href="#ver300a1">α1</a>
<a href="#ver300a2">α2</a>
<a href="#ver300a3">α3</a>
<a href="#ver300a4">α4</a>
<a href="#ver300a5">α5</a>
<a href="#ver300a6">α6</a>
<a href="#ver300a7">α7</a>
<a href="#ver300b1">β1</a>
</p>
<p>
<a href="history_1.3.php">～ 1.3</a>
<a href="history_1.4.php">1.4</a>
<a href="history_1.5.php">1.5</a>
<a href="history_2.0.php">2.0</a>
<a href="history_2.1.php">2.1</a>
<a href="history_2.2.php">2.2</a>
<a href="history_2.3.php">2.3</a>
</p>

<h2 id="ver302">Ver. 3.0.2 (Rev. 1509) : 2015/05/09 (Sat) 20:08</h2>
<ul>
<li>天候「天狗風」「無風」の効果が一部逆転しているバグ修正</li>
<li>山彦：秘密発言登録時は反響能力の対象外とする仕様変更</li>
<li>一部の役職希望が出来ないことがあるバグ修正</li>
<li>猩々が響狼・文武王を正確に透視できないことがあるバグ修正</li>
<li>覚醒天狼判定が護衛能力判定に先行しているバグ修正</li>
<li>蘇生能力者・イタコの夜の投票不可メッセージが正しくないことがあるバグ修正</li>
</ul>

<h2 id="ver301">Ver. 3.0.1 (Rev. 1236) : 2014/10/30 (Thu) 01:55</h2>
<ul>
<li>天狗の所属陣営を誤判定することがあるバグ修正</li>
<li>愛人を恋人カウントするバグ修正</li>
</ul>

<h2 id="ver300">Ver. 3.0.0 (Rev. 1203) : 2014/10/12 (Sun) 00:17</h2>
<ul>
<li>管理者向け情報追加</li>
<li>天候「新月」仕様変更</li>
<li>天候システム・闇鍋モードの背景画像追加</li>
</ul>

<h2 id="ver300rc1">Ver. 3.0.0 RC1 (Rev. 1193) : 2014/09/14 (Sun) 19:47</h2>
<ul>
<li>固定配役追加モード：U(背信村)追加</li>
<li>出現率変動モード：L(結束村)・M(天道村)追加</li>
<li>天候「天狗風」「無風」「彩雲」「星空」「花吹雪」実装</li>
</ul>

<h2 id="ver300b1">Ver. 3.0.0 β1 (Rev. 1184) : 2014/08/31 (Sun) 05:19</h2>
<ul>
<li>非同期更新システムを仮実装</li>
<li>背景画像変更：配役一覧</li>
<li>天狗：ショック死の仕様を変更</li>
<li>固定配役追加モード：T(天狗村)追加</li>
<li>「天変地異」オプション実装</li>
</ul>

<h2 id="ver300a7">Ver. 3.0.0 α7 (Rev. 1168) : 2014/08/12 (Tue) 02:17</h2>
<ul>
<li>Twitter 投稿モジュールのバージョンアップ</li>
<li>神通力の仕様変更</li>
<li>「流星天狗」「鼻高天狗」実装</li>
</ul>

<h2 id="ver300a6">Ver. 3.0.0 α6 (Rev. 1142) : 2014/07/22 (Tue) 02:37</h2>
<ul>
<li>ソースコードダウンロード削除</li>
<li>人狼襲撃失敗の要因を死亡者メッセージに表示</li>
<li>「文車妖妃」「目目連」「瞳狼」実装</li>
<li>サブ役職「交換日記」実装</li>
</ul>

<h2 id="ver300a5">Ver. 3.0.0 α5 (Rev. 1122) : 2014/07/02 (Wed) 00:09</h2>
<ul>
<li>「奉公童女」のバグ修正</li>
<li>「蛍火」の仕様変更</li>
<li>「沈黙禁止」オプション実装</li>
<li>「一言主神」「尼天狗」「産土神」実装</li>
</ul>

<h2 id="ver300a4">Ver. 3.0.0 α4 (Rev. 1106) : 2014/05/25 (Sun) 00:34</h2>
<ul>
<li>「玩具姫」「西行法師」「奉公童女」実装</li>
</ul>

<h2 id="ver300a3">Ver. 3.0.0 α3 (Rev. 1095) : 2014/04/27 (Sun) 21:31</h2>
<ul>
<li>「紂王」「虎狼」「虎狐」実装</li>
</ul>

<h2 id="ver300a2">Ver. 3.0.0 α2 (Rev. 1068) : 2014/04/07 (Mon) 02:06</h2>
<ul>
<li>「天狗」「大天狗」「木っ端天狗」実装</li>
<li>サブ役職「天狗倒し」実装</li>
</ul>

<h2 id="ver300a1">Ver. 3.0.0 α1 (Rev. 1051) : 2014/02/02 (Sun) 21:13</h2>
<ul>
<li>秘密発言追加</li>
<li>「発言数制限制」「秘密会話あり」オプション実装</li>
</ul>
</body>
</html>
